.. SPARSE documentation master file, created by
   sphinx-quickstart on Tue Nov  7 11:59:42 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to SPARSE's documentation!
==================================

SPARSE indexes >100,000 reference genomes in public databases into hierarchical clusters and uses it to predict origins of metagenomic reads.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started:
   
   installation
   toyexample
   parameter

.. toctree::
   :maxdepth: 2
   :caption: Building Databases:
   
   refseq
   representative
   custom

.. toctree::
   :maxdepth: 2
   :caption: Mapping reads:

   mash
   map


Citation
--------

SPARSE has not been formally published yet. If you use SPARSE please cite the preprint https://www.biorxiv.org/content/early/2017/11/07/215707

Zhemin Zhou, Nina Luhmann, Nabil-Fareed Alikhan, Christopher Quince, Mark Achtman, 'Accurate Reconstruction of Microbial Strains Using Representative Reference Genomes' bioRxiv 215707; doi: https://doi.org/10.1101/215707

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
